Header menu logo Euclid.Rhino

Debug2D Module

A module for drawing Euclid 2D geometry in Rhino. All functions draw on Z=0 plane and use automatic layer naming.

Functions and values

Function or value Description

drawDot (msg, pt)

Full Usage: drawDot (msg, pt)

Parameters:
    msg : string
    pt : Pt

Draws a TextDot at a 2D point with the given message. Layer: "Euclid.Debug2D::drawDot".

msg : string
pt : Pt

drawDotLayer (pt, msg, layer)

Full Usage: drawDotLayer (pt, msg, layer)

Parameters:
    pt : Pt
    msg : string
    layer : string

Draws a TextDot at a 2D point with the given message on the specified layer. The layer will be created if it does not exist.

pt : Pt
msg : string
layer : string

drawLine ln

Full Usage: drawLine ln

Parameters:

Draws a 2D line. Layer: "Euclid.Debug2D::drawLine".

ln : Line2D

drawLineFromTo (a, b)

Full Usage: drawLineFromTo (a, b)

Parameters:

Draws a line between two 2D points. Layer: "Euclid.Debug2D::drawLine".

a : Pt
b : Pt

drawLineFromToLayer (a, b, layer)

Full Usage: drawLineFromToLayer (a, b, layer)

Parameters:
    a : Pt
    b : Pt
    layer : string

Draws a line between two 2D points on the specified layer. The layer will be created if it does not exist.

a : Pt
b : Pt
layer : string

drawLineLayer (ln, layer)

Full Usage: drawLineLayer (ln, layer)

Parameters:

Draws a 2D line on the specified layer. The layer will be created if it does not exist.

ln : Line2D
layer : string

drawPolyLine ps

Full Usage: drawPolyLine ps

Parameters:
    ps : Pt seq

Draws a polyline through a sequence of 2D points. Layer: "Euclid.Debug2D::drawPolyLine".

ps : Pt seq

drawPolyLineLayer (ps, layer)

Full Usage: drawPolyLineLayer (ps, layer)

Parameters:
    ps : Pt seq
    layer : string

Draws a polyline through a sequence of 2D points on the specified layer. The layer will be created if it does not exist.

ps : Pt seq
layer : string

drawPt pt

Full Usage: drawPt pt

Parameters:

Draws a point at a 2D location. Layer: "Euclid.Debug2D::drawPt".

pt : Pt

drawPtLayer (pt, layer)

Full Usage: drawPtLayer (pt, layer)

Parameters:
    pt : Pt
    layer : string

Draws a point at a 2D location on the specified layer. The layer will be created if it does not exist.

pt : Pt
layer : string

Type something to start searching.