Header menu logo Euclid.Rhino

Debug3D Module

A module for drawing Euclid 3D geometry in Rhino. All functions use automatic layer naming.

Functions and values

Function or value Description

drawDot (msg, pt)

Full Usage: drawDot (msg, pt)

Parameters:
    msg : string
    pt : Pnt

Draws a TextDot at a 3D point with the given message. Layer: "Euclid.Debug3D::drawDot".

msg : string
pt : Pnt

drawDotLayer (pt, msg, layer)

Full Usage: drawDotLayer (pt, msg, layer)

Parameters:
    pt : Pnt
    msg : string
    layer : string

Draws a TextDot at a 3D point with the given message on the specified layer. The layer will be created if it does not exist.

pt : Pnt
msg : string
layer : string

drawLine ln

Full Usage: drawLine ln

Parameters:

Draws a 3D line. Layer: "Euclid.Debug3D::drawLine".

ln : Line3D

drawLineFromTo (a, b)

Full Usage: drawLineFromTo (a, b)

Parameters:

Draws a line between two 3D points. Layer: "Euclid.Debug3D::drawLine".

a : Pnt
b : Pnt

drawLineFromToLayer (a, b, layer)

Full Usage: drawLineFromToLayer (a, b, layer)

Parameters:
    a : Pnt
    b : Pnt
    layer : string

Draws a line between two 3D points on the specified layer. The layer will be created if it does not exist.

a : Pnt
b : Pnt
layer : string

drawLineLayer (ln, layer)

Full Usage: drawLineLayer (ln, layer)

Parameters:

Draws a 3D line on the specified layer. The layer will be created if it does not exist.

ln : Line3D
layer : string

drawPolyLine ps

Full Usage: drawPolyLine ps

Parameters:

Draws a polyline through a sequence of 3D points. Layer: "Euclid.Debug3D::drawPolyLine".

ps : Pnt seq

drawPolyLineLayer (ps, layer)

Full Usage: drawPolyLineLayer (ps, layer)

Parameters:
    ps : Pnt seq
    layer : string

Draws a polyline through a sequence of 3D points on the specified layer. The layer will be created if it does not exist.

ps : Pnt seq
layer : string

drawPt pt

Full Usage: drawPt pt

Parameters:

Draws a point at a 3D location. Layer: "Euclid.Debug3D::drawPt".

pt : Pnt

drawPtLayer (pt, layer)

Full Usage: drawPtLayer (pt, layer)

Parameters:
    pt : Pnt
    layer : string

Draws a point at a 3D location on the specified layer. The layer will be created if it does not exist.

pt : Pnt
layer : string

Type something to start searching.