Debug2D Module
A module for drawing Euclid 2D geometry in Rhino. All functions draw on Z=0 plane and use automatic layer naming.
Functions and values
| Function or value |
Description
|
|
Draws a TextDot at a 2D point with the given message. Layer: "Euclid.Debug2D::drawDot".
|
|
Draws a TextDot at a 2D point with the given message on the specified layer. The layer will be created if it does not exist.
|
|
Draws a 2D line. Layer: "Euclid.Debug2D::drawLine".
|
|
|
|
|
|
Draws a 2D line on the specified layer. The layer will be created if it does not exist.
|
|
Draws a polyline through a sequence of 2D points. Layer: "Euclid.Debug2D::drawPolyLine".
|
|
Draws a polyline through a sequence of 2D points on the specified layer. The layer will be created if it does not exist.
|
Draws a point at a 2D location. Layer: "Euclid.Debug2D::drawPt".
|
|
|
Draws a point at a 2D location on the specified layer. The layer will be created if it does not exist.
|
Euclid.Rhino