Debug3D Module
A module for drawing Euclid 3D geometry in Rhino. All functions use automatic layer naming.
Functions and values
| Function or value |
Description
|
|
Draws a TextDot at a 3D point with the given message. Layer: "Euclid.Debug3D::drawDot".
|
|
Draws a TextDot at a 3D point with the given message on the specified layer. The layer will be created if it does not exist.
|
|
Draws a 3D line. Layer: "Euclid.Debug3D::drawLine".
|
|
|
|
|
|
Draws a 3D line on the specified layer. The layer will be created if it does not exist.
|
|
Draws a polyline through a sequence of 3D points. Layer: "Euclid.Debug3D::drawPolyLine".
|
|
Draws a polyline through a sequence of 3D points on the specified layer. The layer will be created if it does not exist.
|
Draws a point at a 3D location. Layer: "Euclid.Debug3D::drawPt".
|
|
|
Draws a point at a 3D location on the specified layer. The layer will be created if it does not exist.
|
Euclid.Rhino